Coverage for tictactoe/urls: 100%

# Coverage for tictactoe/urls : 100%

## 4 statements 4 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 | from django.views.generic import TemplateView from django.conf.urls import patterns, include, url from django.contrib import admin urlpatterns = patterns( '', url(r'^$', TemplateView.as_view(template_name='contest/index.html'), name='index'), url(r'rules$', TemplateView.as_view(template_name='contest/rules.html'), name='rules'), url(r'^upload$', 'tictactoe.contest.views.upload'), url(r'^ranking$', 'tictactoe.contest.views.ranking'), url(r'^entries$', 'tictactoe.contest.views.entries'), url(r'^entries/(?P<uid>\d+)$', 'tictactoe.contest.views.entries'), url(r'^entry/(?P<id>\d+)$', 'tictactoe.contest.views.entry'), url(r'^fight/(?P<id>\d+)$', 'tictactoe.contest.views.fight'), url(r'^login/$', 'django.contrib.auth.views.login', name='login'), url(r'^logout$', 'django.contrib.auth.views.logout', {'next_page': '/'}, name='logout'), url(r'^admin/', include(admin.site.urls)), )